==> DateTime-Locale-1.42.tar.gz: DateTime-Locale-1.42/share/ie.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ie",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  day_stand_alone_abbreviated => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Interlingue",
  month_format_abbreviated => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  month_stand_alone_abbreviated => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  name => "Interlingue",
  native_language => "Interlingue",
  native_name => "Interlingue",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 45,
}

==> DateTime-Locale-1.44.tar.gz: DateTime-Locale-1.44/share/ie.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d.M.y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d.M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "W-'im' 'semane' 'de' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d.M",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMMM => "MMM y",
    yMMMEd => "EEEE d MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "w-'im' 'semane' 'de' Y",
  },
  code => "ie",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.M.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jov.",
    "ven.",
    "sat.",
    "sol.",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "S",
  ],
  day_format_wide => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jov.",
    "ven.",
    "sat.",
    "sol.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "luned\N{U+00ed}",
    "mard\N{U+00ed}",
    "mercurd\N{U+00ed}",
    "joved\N{U+00ed}",
    "venerd\N{U+00ed}",
    "saturd\N{U+00ed}",
    "soled\N{U+00ed}",
  ],
  era_abbreviated => [
    "a.C.",
    "e.C.",
  ],
  era_narrow => [
    "a.C.",
    "e.C.",
  ],
  era_wide => [
    "ante Crist",
    "era Cristan",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Interlingue",
  month_format_abbreviated => [
    "jan.",
    "febr.",
    "mar.",
    "apr.",
    "may",
    "jun.",
    "jul\N{U+00ed}",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "febr.",
    "mar.",
    "apr.",
    "may",
    "jun.",
    "jul\N{U+00ed}",
    "aug.",
    "sept.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "marte",
    "april",
    "may",
    "junio",
    "jul\N{U+00ed}",
    "august",
    "septembre",
    "octobre",
    "novembre",
    "decembre",
  ],
  name => "Interlingue",
  native_language => "Interlingue",
  native_name => "Interlingue",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
